#!/usr/bin/env python3

from asyncio import run
from asyncssh import connect, SSHClientConnectionOptions
from multiprocessing import Process, Queue
from random import choice

class Profile:
    PROFILES = {}

    @classmethod
    def from_os(self, os):
        return self.PROFILES.get(os)()

    def __init_subclass__(cls, os):
        cls.PROFILES[os] = cls

class LinuxProfile(Profile, os='linux'):
    def commands(self):
        yield 'hostname'

class IosProfile(Profile, os='ios'):
    def commands(self):
        yield 'cat /etc/lsb-release'

async def main(input, output):
    options = SSHClientConnectionOptions(username='user', password='password')

    while not input.empty():
        profile = input.get()
        async with connect(m, port=2222, options=options) as conn:
            for c in profile.commands():
                result = await conn.run('hostname')
                output.put(result)

def target(input, output):
    run(main(input, output))

if __name__ == '__main__':
    input = Queue()
    output = Queue()
    machines = [
        ('localhost', 'linux'),
        ('localhost', 'ios'),
        ('localhost', 'linux'),
        ('localhost', 'ios'),
    ]
    for m, os in machines:
        input.put(Profile.from_os(os))
    pool = [Process(target=target, args=[input, output]) for _ in range(3)]
    for p in pool:
        p.start()
    for p in pool:
        p.join()

    while not output.empty():
        print(f'{output.get() = }')
